@@ -1,10 +1,17 @@
 
+import enum
+
 import numpy as np
 
 def L1norm(r1, r2):
     return np.sum(abs(r1 - r2))
 
-from . import simvoltage
-from . import pagerank
+
+class PageRankLanguage(enum.Enum):
+    PYTHON = 0
+    CYTHON = 1
+    FORTRAN = 2
+
 from . import hits
-from .pagerank.GooglePageRank import PageRankLanguage
\ No newline at end of file
+from . import pagerank
+from . import simvoltage
